@@ -18,7 +18,7 @@ bme280.sea_level_pressure = 1013.25
 
 while True:
     print("\nTemperature: %0.1f C" % bme280.temperature)
-    print("Humidity: %0.1f %%" % bme280.humidity)
+    print("Humidity: %0.1f %%" % bme280.relative_humidity)
     print("Pressure: %0.1f hPa" % bme280.pressure)
     print("Altitude = %0.2f meters" % bme280.altitude)
     time.sleep(2)
